==> merge-hris-client-1.0.2.tar.gz: merge-hris-client-1.0.2/MergeHRISClient/apis/__init__.py <==

# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.account_token_api import AccountTokenApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from MergeHRISClient.api.account_token_api import AccountTokenApi
from MergeHRISClient.api.available_actions_api import AvailableActionsApi
from MergeHRISClient.api.benefits_api import BenefitsApi
from MergeHRISClient.api.companies_api import CompaniesApi
from MergeHRISClient.api.employee_payroll_runs_api import EmployeePayrollRunsApi
from MergeHRISClient.api.employees_api import EmployeesApi
from MergeHRISClient.api.employments_api import EmploymentsApi
from MergeHRISClient.api.generate_key_api import GenerateKeyApi
from MergeHRISClient.api.link_token_api import LinkTokenApi
from MergeHRISClient.api.locations_api import LocationsApi
from MergeHRISClient.api.passthrough_api import PassthroughApi
from MergeHRISClient.api.payroll_runs_api import PayrollRunsApi
from MergeHRISClient.api.regenerate_key_api import RegenerateKeyApi
from MergeHRISClient.api.sync_status_api import SyncStatusApi
from MergeHRISClient.api.teams_api import TeamsApi
from MergeHRISClient.api.time_off_api import TimeOffApi
from MergeHRISClient.api.time_off_balance_api import TimeOffBalanceApi

==> merge-hris-client-1.2.1.tar.gz: merge-hris-client-1.2.1/MergeHRISClient/apis/__init__.py <==

# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.account_details_api import AccountDetailsApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from MergeHRISClient.api.account_details_api import AccountDetailsApi
from MergeHRISClient.api.account_token_api import AccountTokenApi
from MergeHRISClient.api.available_actions_api import AvailableActionsApi
from MergeHRISClient.api.bank_info_api import BankInfoApi
from MergeHRISClient.api.benefits_api import BenefitsApi
from MergeHRISClient.api.companies_api import CompaniesApi
from MergeHRISClient.api.deductions_api import DeductionsApi
from MergeHRISClient.api.delete_account_api import DeleteAccountApi
from MergeHRISClient.api.employee_payroll_runs_api import EmployeePayrollRunsApi
from MergeHRISClient.api.employees_api import EmployeesApi
from MergeHRISClient.api.employments_api import EmploymentsApi
from MergeHRISClient.api.generate_key_api import GenerateKeyApi
from MergeHRISClient.api.issues_api import IssuesApi
from MergeHRISClient.api.link_token_api import LinkTokenApi
from MergeHRISClient.api.linked_accounts_api import LinkedAccountsApi
from MergeHRISClient.api.locations_api import LocationsApi
from MergeHRISClient.api.passthrough_api import PassthroughApi
from MergeHRISClient.api.payroll_runs_api import PayrollRunsApi
from MergeHRISClient.api.regenerate_key_api import RegenerateKeyApi
from MergeHRISClient.api.sync_status_api import SyncStatusApi
from MergeHRISClient.api.teams_api import TeamsApi
from MergeHRISClient.api.time_off_api import TimeOffApi
from MergeHRISClient.api.time_off_balance_api import TimeOffBalanceApi
